==> aroundme_0_5_1.zip: aroundme_0_5_1/aroundme/language/1/barnraiser_01/sn_profile.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'sn_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_block'] = 							"block";
$lang['hdr_contact'] = 							"contact details";
$lang['hdr_relationship'] = 					"relationship";
$lang['hdr_summary'] =							"summary";


//A HREF TAGS (links)
$lang['href_unblock'] = 						"unblock this user";


//SUBMIT BUTTONS
$lang['sub_block'] = 							"block them";


//PROFILE ADDONS
// leave these blank if you do not want them to show in forms and on pages.
$lang['txt_profile_text1'] =					"Microsoft messenger (MSN) ID";
$lang['txt_profile_text2'] =					"Yahoo ID";
$lang['txt_profile_text3'] =					"ICQ number";
$lang['txt_profile_text4'] = 					"Mobile phone";
$lang['txt_profile_text5'] = 					"Skype";
$lang['txt_profile_text6'] = 					"Job title";
$lang['txt_profile_text7'] = 					"";
$lang['txt_profile_text8'] = 					"";
$lang['txt_profile_text9'] = 					"";
$lang['txt_profile_text10'] = 					"";


//BODY TEXT
$lang['txt_block_description_text'] = 			"If you choose to block a person you will stop them from sending you instant messages, stop them from inviting you as a new friend and stop them from seeing your profile, library and blog. You will see them listed under your blocked list. You can choose to enter a description of why you blocked them which will act as a reminder to you in the future.";


//$lang['hdr_blocked'] = 							"blocked";
//$lang['href_blocked_list'] = 					"see blocked user list";
//$lang['hdr_profile'] =							"profile";
//$lang['hdr_statistics'] = 						"statistics";
//$lang['txt_profile_summary'] = 					"summary";
//$lang['txt_blocked_help'] = 					"This person is blocked.";
//$lang['txt_block_description'] = 				"description";
//titles
//$lang['ttl_send_message'] = 					"send message";

?>

==> aroundme_0_5_3.zip: aroundme_0_5_3/aroundme/language/1/barnraiser_01/sn_profile.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'sn_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_block'] = 							"block";
$lang['hdr_contact'] = 							"contact details";
$lang['hdr_relationship'] = 					"relationship";
$lang['hdr_summary'] =							"summary";
$lang['hdr_tag'] = 								"tags";
$lang['hdr_groups'] =							"groups";


//A HREF TAGS (links)
$lang['href_unblock'] = 						"unblock this user";


//SUBMIT BUTTONS
$lang['sub_block'] = 							"block them";
$lang['sub_update_tag'] = 						"update my tags";


//PROFILE ADDONS
// leave these blank if you do not want them to show in forms and on pages.
$lang['txt_profile_text1'] =					"Microsoft messenger (MSN) ID";
$lang['txt_profile_text2'] =					"Yahoo ID";
$lang['txt_profile_text3'] =					"ICQ number";
$lang['txt_profile_text4'] = 					"Mobile phone";
$lang['txt_profile_text5'] = 					"Skype";
$lang['txt_profile_text6'] = 					"Job title";
$lang['txt_profile_text7'] = 					"";
$lang['txt_profile_text8'] = 					"";
$lang['txt_profile_text9'] = 					"";
$lang['txt_profile_text10'] = 					"";


//BODY TEXT
$lang['txt_block_description_text'] = 			"If you choose to block a person you will stop them from sending you instant messages, stop them from inviting you as a new friend and stop them from seeing your profile, library and blog. You will see them listed under your blocked list. You can choose to enter a description of why you blocked them which will act as a reminder to you in the future.";
$lang['txt_tag_intro'] = 						"This person has been tagged with";

?>
